==> qttranslations-opensource-src-5.6.2.tar.xz: qttranslations-opensource-src-5.6.2/translations/qtwebengine_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Требуется авторизация</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <source>&amp;Log In</source>
        <translation>&amp;Войти</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Follow Link</source>
        <translation>Перейти по ссылке</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Впeрёд</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопировать</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Скопировать адрес ссылки</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Сохранить ссылку</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Скопировать адрес изображения</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Скопировать изображение</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Сохранить изображение</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Скопировать адрес ресурса</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Сохранить ресурс</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Воспроизвести/приостановить</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Зациклено</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Управление воспроизведением</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Исследовать элемент</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперёд</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопировать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторить</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Выделить всё</translation>
    </message>
    <message>
        <source>Paste and Match Style</source>
        <translation>Вставить со стилем</translation>
    </message>
    <message>
        <source>Open Link in This Window</source>
        <translation>Открыть ссылку в этом окне</translation>
    </message>
    <message>
        <source>Open Link in New Window</source>
        <translation>Открыть ссылку в новом окне</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Открыть ссылку в новой вкладке</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Скопировать адрес ссылки</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Сохранить ссылку</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Скопировать изображение</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Скопировать адрес изображения</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Сохранить изображение</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Скопировать адрес ресурса</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Управление воспроизведением</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Зациклено</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Воспроизвести/приостановить</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Сохранить ресурс</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Исследовать элемент</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Закрыть страницу</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Закрыть страницу?</translation>
    </message>
    <message>
        <source>Follow Link</source>
        <translation>Перейти по ссылке</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперёд</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Перезагрузить</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Выберите каталог для отправки</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Извещение Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Подтверждение Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Приглашение Javascript - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Закрыть страницу?</translation>
    </message>
</context>
<context>
    <name>QtWebEngineExperimentalPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineViewExperimental</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineViewExperimental</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineViewport</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineViewport</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create separate instance of WebEngineLoadRequest</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineLoadRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNavigationRequest</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineNavigationRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineCertificateError</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineCertificateError</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineDownloadItem</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineNewViewRequest</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineSettings</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineSettings</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Невозможно создать отдельный экземпляр NavigationHistory</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Невозможно создать отдельный экземпляр FullScreenRequest</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineErrorPage</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Подключение к прокси «%1» с использованием:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>Введите имя пользователя и пароль для «%1» в %2://%3</translation>
    </message>
</context>
</TS>

==> qttranslations-opensource-src_5.9.5.orig.tar.xz: qttranslations-opensource-src-5.9.5/translations/qtwebengine_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Требуется авторизация</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <source>&amp;Log In</source>
        <translation>&amp;Войти</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Follow Link</source>
        <translation>Перейти по ссылке</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Впeрёд</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопировать</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Снять выделение</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Скопировать адрес ссылки</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Сохранить ссылку</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Скопировать адрес изображения</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Скопировать изображение</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Сохранить изображение</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Скопировать адрес ресурса</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Сохранить ресурс</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Воспроизвести/приостановить</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Зациклено</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Управление воспроизведением</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Исследовать элемент</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперёд</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation>Перезагрузить без кэша</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопировать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторить</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Выделить всё</translation>
    </message>
    <message>
        <source>Paste and Match Style</source>
        <translation>Вставить со стилем</translation>
    </message>
    <message>
        <source>Open Link in This Window</source>
        <translation>Открыть ссылку в этом окне</translation>
    </message>
    <message>
        <source>Open Link in New Window</source>
        <translation>Открыть ссылку в новом окне</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Открыть ссылку в новой вкладке</translation>
    </message>
    <message>
        <source>Open Link in New Background Tab</source>
        <translation>Открыть ссылку в новой фоновой вкладке</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Скопировать адрес ссылки</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Сохранить ссылку</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Скопировать изображение</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Скопировать адрес изображения</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Сохранить изображение</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Скопировать адрес ресурса</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Управление воспроизведением</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Зациклено</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Воспроизвести/приостановить</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Сохранить ресурс</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Исследовать элемент</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Закрыть страницу</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Снять выделение</translation>
    </message>
    <message>
        <source>Save &amp;Page</source>
        <translation>Сохранить страни&amp;цу</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Закрыть страницу?</translation>
    </message>
    <message>
        <source>Follow Link</source>
        <translation>Перейти по ссылке</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперёд</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Перезагрузить</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Выберите каталог для отправки</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Извещение Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Подтверждение Javascript - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Приглашение Javascript - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Закрыть страницу?</translation>
    </message>
</context>
<context>
    <name>QtWebEngineExperimentalPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineViewExperimental</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineViewExperimental</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineViewport</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineViewport</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineContextMenuData</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineContextMenuData</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create separate instance of WebEngineLoadRequest</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineLoadRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNavigationRequest</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineNavigationRequest</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineCertificateError</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineCertificateError</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineDownloadItem</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineNewViewRequest</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineSettings</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineSettings</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Невозможно создать отдельный экземпляр NavigationHistory</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Невозможно создать отдельный экземпляр FullScreenRequest</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Невозможно создать отдельный экземпляр WebEngineErrorPage</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Подключение к прокси «%1» с использованием:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>Введите имя пользователя и пароль для «%1» в %2://%3</translation>
    </message>
</context>
</TS>
